@@ -58,11 +58,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.478
+Version 0.479
 
 =cut
 
-our $VERSION = '0.478';
+our $VERSION = '0.479';
 
 
 =head2 Development status
@@ -1194,6 +1194,15 @@ L<App::Dochazka::REST> offers the following debug facilities:
 
 =over
 
+=item * C<bin/dochazka-rest -- --early-debug=$TMPFILE>
+
+Calling the server startup script as shown will cause the C<--early-debug>
+parameter to be passed through to C<bin/mrest> (from the L<Web::MREST> distro).
+This has the interesting effect of capturing even the earliest debug messages
+to a temporary file, which the server must be able to C<touch>. Once the server
+has started, the filename can also be determined by sending a C<GET
+param/meta/MREST_EARLY_DEBUGGING> request.
+
 =item * DOCHAZKA_DEBUG environment variable
 
 If the C<DOCHAZKA_DEBUG> environment variable is set to a true value, the
@@ -1210,77 +1219,6 @@ debug messages will be logged.
 =head1 METHODS
 
 
-
-=head2 init_no_db
-
-Load site configuration and set up logging.
-
-Takes an optional PARAMHASH which is passed to C<< _load_config() >>. This
-PARAMHASH can be used to stipulate a C<<sitedir>> and toggle verbose and debug
-modes.
-
-The L<App::Dochazka::REST> distro sharedir is loaded as the first sitedir,
-before any sitedir specified in the PARAMHASH is loaded. Call examples:
-
-    my $status = $REST->init_no_db;
-    my $status = $REST->init_no_db( verbose => 1 );
-    my $status = $REST->init_no_db( sitedir => '/etc/fooapp' );
-
-=cut
-
-sub init_no_db {
-    my $self = shift;
-    my %ARGS = validate( @_, { 
-        sitedir => { type => SCALAR, optional => 1 },
-        verbose => { type => SCALAR, optional => 1 },
-        debug_mode => { type => SCALAR, optional => 1 },
-    } );
-    $log->info( Dumper( \%ARGS ) ) if $ARGS{verbose};
-
-    # * load site configuration
-    my $status = _load_config( %ARGS );
-    return $status if $status->not_ok;
-
-    # * set up logging
-    return $CELL->status_not_ok( "DOCHAZKA_APPNAME not set!" ) if not $site->DOCHAZKA_APPNAME;
-    my $debug_mode;
-    if ( exists $ARGS{'debug_mode'} ) {
-        $debug_mode = $ARGS{'debug_mode'};
-    } else {
-        $debug_mode = $site->DOCHAZKA_REST_DEBUG_MODE || 0;
-    }
-    my $logfile = normalize_filespec( $site->DOCHAZKA_REST_LOG_FILE );
-    unlink $logfile if $site->DOCHAZKA_REST_LOG_FILE_RESET;
-    Log::Any::Adapter->set('File', $logfile );
-    $log->init( ident => $site->DOCHAZKA_APPNAME, debug_mode => $debug_mode );
-    $log->info( "Initializing " . $site->DOCHAZKA_APPNAME );
-
-    return $CELL->status_ok;
-}
-
-sub _load_config {
-    my %ARGS = @_;
-    my $status;
-    my $verbose = $ARGS{verbose} || 0;
-    $log->debug( "Entering _load_config with verbose => $verbose" ) if $ARGS{verbose};
-
-    # always load the App::Dochazka::REST distro sharedir
-    my $target = File::ShareDir::dist_dir('App-Dochazka-REST');
-    $log->debug( "About to load Dochazka-REST configuration parameters from $target" );
-    $status = $CELL->load( sitedir => $target, verbose => $verbose );
-    return $status if $status->not_ok;
-
-    # load additional sitedir if provided by caller in argument list
-    if ( $ARGS{sitedir} ) {
-        $status = $CELL->load( sitedir => $ARGS{sitedir}, verbose => $verbose );
-        return $status if $status->not_ok;
-    }
-
-    return $CELL->status_ok;
-}
-
-
-
 =head2 run_sql
 
 Takes a L<DBIx::Connector> object and an array of SQL statements. Runs them 
